@@ -1,4 +1,4 @@
-from typing import Dict, List, Optional, final
+from typing import Dict, List, NoReturn, Optional, final
 
 from .base import BaseService
 
@@ -11,7 +11,9 @@ class PrintMixin:
         object_methods = [
             method_name
             for method_name in dir(self)
-            if callable(getattr(self, method_name)) and not method_name.startswith("_")
+            if callable(getattr(self, method_name))
+            and not method_name.startswith("_")
+            and getattr(self, method_name).__annotations__.get("return") is not NoReturn
         ]
         object_attributes = [
             attribute_name
@@ -70,12 +72,7 @@ class NameMixin:
 
     def get_id(self, name_or_slug: str) -> Optional[int]:
         """Get the ID for an object by name or slug, returns None if not found"""
-        all_obj: List[Dict] = self.get_all()
-
-        if "results" in all_obj:
-            all_obj = all_obj["results"]
-
-        for obj in all_obj:
+        for obj in self.get_all():
             if obj.get("name") == name_or_slug or obj.get("slug") == name_or_slug:
                 return obj.get("id")
 
